@@ -301,7 +301,7 @@ class fetch_files(object):
         radio_filter_activate = ttk.Radiobutton(frame_filter_button, 
                                        variable=self.filter_opt, 
                                        value='activate',
-                                       text='By activatation',
+                                       text='By activation',
                                        )
         radio_filter_remove = ttk.Radiobutton(frame_filter_button, 
                                        variable=self.filter_opt, 
@@ -791,7 +791,7 @@ class fetch_files(object):
         """
 
         # don't hide if mousing over history
-        if obj == 'entry' and 0 < event.x < 800 and event.y > 0:
+        if obj == 'entry' and 0 < event.x < self.entry_run.winfo_reqwidth() and event.y > 0:
             return  
         
         # hide the history box    
